@@ -7,14 +7,13 @@ from Products.Five import fiveconfigure
 from Products.PloneTestCase import PloneTestCase as ptc
 from Products.PloneTestCase.layer import onsetup, onteardown
 
-from pmr2.testing import base
-
 
 @onsetup
 def setup():
     import pmr2.captcha
     fiveconfigure.debug_mode = True
     zcml.load_config('configure.zcml', pmr2.captcha)
+    zcml.load_config('test.zcml', pmr2.captcha.tests)
     fiveconfigure.debug_mode = False
     ztc.installPackage('pmr2.captcha')
 
